==> pyconnectwise-0.4.5.tar.gz: pyconnectwise-0.4.5/src/pyconnectwise/endpoints/manage/ProcurementWarehousesEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.ProcurementWarehousesCountEndpoint import ProcurementWarehousesCountEndpoint
from pyconnectwise.endpoints.manage.ProcurementWarehousesIdEndpoint import ProcurementWarehousesIdEndpoint
from pyconnectwise.endpoints.manage.ProcurementWarehousesInfoEndpoint import ProcurementWarehousesInfoEndpoint
from pyconnectwise.models.manage import Warehouse
from pyconnectwise.responses.paginated_response import PaginatedResponse


class ProcurementWarehousesEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "warehouses", parent_endpoint=parent_endpoint)

        self.info = self._register_child_endpoint(ProcurementWarehousesInfoEndpoint(client, parent_endpoint=self))
        self.count = self._register_child_endpoint(ProcurementWarehousesCountEndpoint(client, parent_endpoint=self))

    def id(self, id: int) -> ProcurementWarehousesIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized ProcurementWarehousesIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            ProcurementWarehousesIdEndpoint: The initialized ProcurementWarehousesIdEndpoint object.
        """
        child = ProcurementWarehousesIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(self, page: int, page_size: int, params: dict[str, int | str] = {}) -> PaginatedResponse[Warehouse]:
        """
        Performs a GET request against the /procurement/warehouses endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[Warehouse]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params),
            Warehouse,
            self,
            page,
            page_size,
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[Warehouse]:
        """
        Performs a GET request against the /procurement/warehouses endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[Warehouse]: The parsed response data.
        """
        return self._parse_many(Warehouse, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> Warehouse:
        """
        Performs a POST request against the /procurement/warehouses endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            Warehouse: The parsed response data.
        """
        return self._parse_one(Warehouse, super()._make_request("POST", data=data, params=params).json())

==> pyconnectwise-0.4.7.tar.gz: pyconnectwise-0.4.7/src/pyconnectwise/endpoints/manage/ProcurementWarehousesEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.ProcurementWarehousesCountEndpoint import ProcurementWarehousesCountEndpoint
from pyconnectwise.endpoints.manage.ProcurementWarehousesIdEndpoint import ProcurementWarehousesIdEndpoint
from pyconnectwise.endpoints.manage.ProcurementWarehousesInfoEndpoint import ProcurementWarehousesInfoEndpoint
from pyconnectwise.models.manage import Warehouse
from pyconnectwise.responses.paginated_response import PaginatedResponse


class ProcurementWarehousesEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "warehouses", parent_endpoint=parent_endpoint)

        self.count = self._register_child_endpoint(ProcurementWarehousesCountEndpoint(client, parent_endpoint=self))
        self.info = self._register_child_endpoint(ProcurementWarehousesInfoEndpoint(client, parent_endpoint=self))

    def id(self, id: int) -> ProcurementWarehousesIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized ProcurementWarehousesIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            ProcurementWarehousesIdEndpoint: The initialized ProcurementWarehousesIdEndpoint object.
        """
        child = ProcurementWarehousesIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(self, page: int, page_size: int, params: dict[str, int | str] = {}) -> PaginatedResponse[Warehouse]:
        """
        Performs a GET request against the /procurement/warehouses endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[Warehouse]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(super()._make_request("GET", params=params), Warehouse, self, page, page_size, params)

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[Warehouse]:
        """
        Performs a GET request against the /procurement/warehouses endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[Warehouse]: The parsed response data.
        """
        return self._parse_many(Warehouse, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> Warehouse:
        """
        Performs a POST request against the /procurement/warehouses endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            Warehouse: The parsed response data.
        """
        return self._parse_one(Warehouse, super()._make_request("POST", data=data, params=params).json())
